@@ -1,7 +1,7 @@
 
 package MIME::Types;
 use vars '$VERSION';
-$VERSION = '1.13';
+$VERSION = '1.17';
 
 use strict;
 
@@ -109,11 +109,7 @@ sub addType(@)
 {   my $self = shift;
 
     foreach my $type (@_)
-    {
-        carp "WARNING: type $type already registered."
-            if $type->isRegistered;
-
-        my $simplified = $type->simplified;
+    {   my $simplified = $type->simplified;
         push @{$list{$simplified}}, $type;
     }
 
@@ -124,6 +120,26 @@ sub addType(@)
 #-------------------------------------------
 
 
+sub types
+{   my $self = shift;
+
+    $self->create_type_index unless keys %type_index;
+    return values %type_index;
+}
+                                                                                
+#-------------------------------------------
+
+
+sub extensions
+{    my $self = shift;
+    $self->create_type_index unless keys %type_index;
+
+    return keys %type_index;
+}
+                                                                                
+#-------------------------------------------
+
+
 #-------------------------------------------
 
 require Exporter;
@@ -187,8 +203,7 @@ CROAK
 
 #-------------------------------------------
 # Internet media type registry is at
-# <http://www.iana.org/assignments/media-types/> and
-# F<ftp://ftp.iana.org/in-notes/iana/assignments/media-types/>.
+# http://www.iana.org/assignments/media-types/
 
 $mime_type_definitions = <<MIMETYPES;
 application/activemessage
@@ -207,6 +222,7 @@ application/DCA-RFT
 application/DEC-DX
 application/dicom
 application/dvcs
+application/ecmascript
 application/EDI-Consent
 application/EDIFACT
 application/EDI-X12
@@ -223,6 +239,7 @@ application/index.vnd
 application/iotp
 application/ipp
 application/isup
+application/javascript		js				8bit
 application/mac-binhex40	hqx				8bit
 application/macwriteii
 application/marc
@@ -255,6 +272,7 @@ application/prs.cww		cw,cww
 application/prs.nprend		rnd,rct
 application/prs.plucker
 application/qsig
+application/rdf+xml		rdf				8bit
 application/reginfo+xml
 application/remote-printing
 application/riscos
@@ -268,7 +286,7 @@ application/sgml
 application/sgml-open-catalog	soc
 application/sieve		siv
 application/slate
-application/smil		smi,smil
+application/smil		smi,smil			8bit
 application/timestamp-query
 application/timestamp-reply
 application/toolbook		tbk
@@ -329,6 +347,7 @@ application/vnd.ericsson.quickcall
 application/vnd.eudora.data
 application/vnd.fdf
 application/vnd.ffsns
+application/vnd.fints
 application/vnd.FloGraphIt
 application/vnd.framemaker
 application/vnd.fsc.weblauch	fsc			7bit
@@ -394,11 +413,13 @@ application/vnd.kde.kword	kwd,kwt
 application/vnd.kenameapp	htke
 application/vnd.kidspiration	kia
 application/vnd.Kinar		kne,knp,sdf
+application/vnd.google-earth.kml+xml			kml	8bit
+application/vnd.google-earth.kmz			kmz	8bit
 application/vnd.koan
 application/vnd.liberty-request+xml
 application/vnd.llamagraphics.life-balance.desktop	lbd
 application/vnd.llamagraphics.life-balance.exchange+xml	lbe
-application/vnd.lotus-1-2-3	wks
+application/vnd.lotus-1-2-3	wks,123
 application/vnd.lotus-approach
 application/vnd.lotus-freelance
 application/vnd.lotus-notes
@@ -408,6 +429,7 @@ application/vnd.lotus-wordpro
 application/vnd.mcd		mcd
 application/vnd.mediastation.cdkey
 application/vnd.meridian-slingshot
+application/vnd.mfmp			mfm
 application/vnd.micrografx.flo	flo
 application/vnd.micrografx.igx	igx
 application/vnd.mif		mif
@@ -493,8 +515,20 @@ application/vnd.sss-cod
 application/vnd.sss-dtf
 application/vnd.sss-ntf
 application/vnd.street-stream
+application/vnd.sun.xml.calc		sxc
+application/vnd.sun.xml.calc.template	stc
+application/vnd.sun.xml.draw		sxd
+application/vnd.sun.xml.draw.template	std
+application/vnd.sun.xml.impress		sxi
+application/vnd.sun.xml.impress.template	sti
+application/vnd.sun.xml.math		sxm
+application/vnd.sun.xml.writer		sxw
+application/vnd.sun.xml.writer.global	sxg
+application/vnd.sun.xml.writer.template	stw
+application/vnd.sus-calendar	sus,susp
 application/vnd.svd
 application/vnd.swiftview-ics
+application/vnd.syncml.ds.notification
 application/vnd.triscape.mxs
 application/vnd.trueapp
 application/vnd.truedoc
@@ -545,6 +579,7 @@ application/watcherinfo+xml		wif
 application/whoispp-query
 application/whoispp-response
 application/wita
+application/wordperfect5.1	wp5,wp
 application/x-123		wk
 application/x-access
 application/x-bcpio		bcpio
@@ -579,7 +614,6 @@ application/x-ideas
 application/x-imagemap		imagemap,imap			8bit
 application/x-java-archive	jar
 application/x-java-jnlp-file	jnlp
-application/x-javascript	js				8bit
 application/x-java-serialized-object	ser
 application/x-java-vm		class
 application/x-koan		skp,skd,skt,skm
@@ -587,7 +621,7 @@ application/x-latex		latex				8bit
 application/x-lotus-123
 application/x-mac-compactpro	cpt
 application/x-maker		frm,maker,frame,fm,fb,book,fbdoc
-application/x-mathcad		mcd
+application/x-mathcad	# mcd, but there is also vnd.mcd
 application/x-mif		mif
 application/xml
 application/xml-dtd
@@ -631,13 +665,12 @@ application/x-VMSBACKUP		bck			base64
 application/x-wais-source	src
 application/x-Wingz		wz
 application/x-word							base64
-application/x-wordperfect5.1	wp5,wp
 application/x-wordperfect6.1	wp6
 application/x-x400-bp
 application/x-x509-ca-cert	crt				base64
 application/zip			zip				base64
-applivation/vnd.fints
 audio/32kadpcm
+audio/3gpp			3gpp
 audio/AMR			amr				base64
 audio/AMR-WB			awb				base64
 audio/basic			au,snd				base64
@@ -841,6 +874,7 @@ text/x-setext				etx
 text/x-sgml				sgml,sgm			8bit
 text/x-vCalendar			vcs				8bit
 text/x-vCard				vcf				8bit
+video/3gpp				3gp,3gpp
 video/BMPEG
 video/BT656
 video/CelB
@@ -878,6 +912,7 @@ video/vnd.sealed.swf			sswf,ssw
 video/vnd.vivo				viv,vivo
 video/x-fli				fli				base64
 video/x-ms-asf				asf,asx
+video/x-ms-wmv				wmv
 video/x-msvideo				avi				base64
 video/x-sgi-movie			movie				base64
 x-chemical/x-pdb			pdb
